pub enum AppStorageSessionRequest {
Paths(AppPathBuilder),
StoragePlan(AppStoragePlanBuilder),
Migration(StorageMigrationPlanBuilder),
Cleanup(StorageCleanupPlanBuilder),
HostedProfileStorage {
profile_id: String,
},
}Expand description
A checked app storage/session descriptor for builder and agent flows.
Variants
Paths(AppPathBuilder)
Resolve app-owned paths before opening storage.
StoragePlan(AppStoragePlanBuilder)
Prepare app-owned storage entries.
Migration(StorageMigrationPlanBuilder)
Run storage migrations.
Cleanup(StorageCleanupPlanBuilder)
Run storage cleanup.
HostedProfileStorage
Delegate browser-owned profile state to a scoped WebView storage key.
Implementations
Sourceimpl AppStorageSessionRequest
impl AppStorageSessionRequest
Sourcepub fn is_storage_plan(&self) -> bool
pub fn is_storage_plan(&self) -> bool
Return true when this request prepares app storage.
Sourcepub fn is_migration(&self) -> bool
pub fn is_migration(&self) -> bool
Return true when this request runs migrations.
Sourcepub fn is_cleanup(&self) -> bool
pub fn is_cleanup(&self) -> bool
Return true when this request runs cleanup.
Sourcepub fn is_hosted_profile_storage(&self) -> bool
pub fn is_hosted_profile_storage(&self) -> bool
Return true when this request delegates profile state to a hosted WebView.
Sourcepub fn next_action(&self) -> AppStorageSessionNextAction
pub fn next_action(&self) -> AppStorageSessionNextAction
Return the next product action implied by this request.
Sourcepub fn path_builder(&self) -> Option<&AppPathBuilder>
pub fn path_builder(&self) -> Option<&AppPathBuilder>
Return the path builder when configured.
Sourcepub fn storage_plan_builder(&self) -> Option<&AppStoragePlanBuilder>
pub fn storage_plan_builder(&self) -> Option<&AppStoragePlanBuilder>
Return the storage-plan builder when configured.
Sourcepub fn migration_builder(&self) -> Option<&StorageMigrationPlanBuilder>
pub fn migration_builder(&self) -> Option<&StorageMigrationPlanBuilder>
Return the migration builder when configured.
Sourcepub fn cleanup_builder(&self) -> Option<&StorageCleanupPlanBuilder>
pub fn cleanup_builder(&self) -> Option<&StorageCleanupPlanBuilder>
Return the cleanup builder when configured.
Sourcepub fn hosted_profile_id(&self) -> Option<&str>
pub fn hosted_profile_id(&self) -> Option<&str>
Return the hosted profile id when configured.