pub enum WebViewPermissionDecision {
Default,
Allow,
Deny,
}Expand description
App decision for both native WebView permission policy and JavaScript permission preflighting.
Variants
Default
Continue with the embedded browser’s normal permission behavior. On Linux, the underlying WebKitGTK default is to deny the request.
Allow
Grant the native request, or allow a preflighted page API to continue.
Deny
Deny the native request, or block a preflighted page API.