pub enum WindowContentProtectionMode {
Disabled,
ExcludeFromCapture,
ObscureWhenCaptured,
}Expand description
Desired capture/privacy behavior for a native window.
Variants
Disabled
Allow normal OS capture behavior.
ExcludeFromCapture
Request that the OS exclude the window from screenshots and screen capture.
ObscureWhenCaptured
Request that captured output is obscured when full exclusion is unavailable.
Implementations