pub fn menu_button<T, I, O>(id: impl Into<ElementId>, items: I) -> MenuButton<T>Expand description
Construct a menu button primitive backed by an anchored popup menu.
pub fn menu_button<T, I, O>(id: impl Into<ElementId>, items: I) -> MenuButton<T>Construct a menu button primitive backed by an anchored popup menu.