pub struct ProcessContextSwitchReport { /* private fields */ }Expand description
Report returned after switching the app’s active capability process context.
Implementations
Sourceimpl ProcessContextSwitchReport
impl ProcessContextSwitchReport
Sourcepub fn previous_process_id(&self) -> ProcessId
pub fn previous_process_id(&self) -> ProcessId
Process id used before the switch.
Sourcepub fn process_id(&self) -> ProcessId
pub fn process_id(&self) -> ProcessId
Process id now used for app capability checks.
Sourcepub fn process_class(&self) -> ProcessClass
pub fn process_class(&self) -> ProcessClass
Process class registered for the active process id.
Sourcepub fn registered_process(&self) -> bool
pub fn registered_process(&self) -> bool
Whether the checked switch registered this process id before activation.
Sourcepub fn granted_capabilities(&self) -> &[Capability]
pub fn granted_capabilities(&self) -> &[Capability]
Capabilities visible to the active process after the switch.
Sourcepub fn granted_capability_count(&self) -> usize
pub fn granted_capability_count(&self) -> usize
Number of capabilities visible after the switch.
Sourcepub fn grants(&self, capability: &Capability) -> bool
pub fn grants(&self, capability: &Capability) -> bool
Whether the active process has the given capability after the switch.