#[non_exhaustive]pub struct ScrollBarRenderState {
pub vertical: bool,
pub logical_offset: Pixels,
pub max_offset: Pixels,
pub viewport_size: Pixels,
pub content_size: Pixels,
pub percentage: f64,
pub thumb_ratio: f64,
pub dragging: bool,
pub focused: bool,
pub opacity: f32,
}Expand description
Snapshot of scroll bar state passed to a custom renderer.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.vertical: boolWhether the scroll bar is vertical.
logical_offset: PixelsThe current logical scroll offset, expressed as a positive distance from the start.
max_offset: PixelsThe maximum logical scroll offset.
viewport_size: PixelsThe size of the visible viewport along the scrolling axis.
content_size: PixelsThe total content size along the scrolling axis.
percentage: f64Current thumb position expressed as a value between 0.0 and 1.0.
thumb_ratio: f64Thumb size expressed as a fraction of the track length.
dragging: boolWhether the scroll bar is currently being dragged.
focused: boolWhether the scroll bar currently owns keyboard focus.
opacity: f32Visual opacity of the scroll bar (0.0 = hidden, 1.0 = fully visible).
Implementations