pub struct SystemIdlePolicy { /* private fields */ }Expand description
A checked policy for deciding when the system has been idle long enough.
Implementations
Sourceimpl SystemIdlePolicy
impl SystemIdlePolicy
Sourcepub fn builder(threshold: Duration) -> SystemIdlePolicyBuilder
pub fn builder(threshold: Duration) -> SystemIdlePolicyBuilder
Create an idle policy builder with the required idle threshold.
Sourcepub fn requires_known_idle_time(&self) -> bool
pub fn requires_known_idle_time(&self) -> bool
Return whether idle time must be known for the policy to match.
Sourcepub fn treats_unknown_as_idle(&self) -> bool
pub fn treats_unknown_as_idle(&self) -> bool
Return whether missing idle data should be treated as idle.
Sourcepub fn evaluate(&self, snapshot: &SystemPowerSnapshot) -> SystemIdleEvaluation
pub fn evaluate(&self, snapshot: &SystemPowerSnapshot) -> SystemIdleEvaluation
Evaluate a system power snapshot against this policy.
Sourcepub fn allows(&self, snapshot: &SystemPowerSnapshot) -> bool
pub fn allows(&self, snapshot: &SystemPowerSnapshot) -> bool
Return true when idle-gated work should run for this snapshot.