pub struct DrawContext { /* private fields */ }Expand description
Immediate-mode drawing context used by canvas(size, draw).
Implementations
Sourceimpl DrawContext
impl DrawContext
Sourcepub fn bounds(&self) -> Bounds<Pixels>
pub fn bounds(&self) -> Bounds<Pixels>
Returns the canvas-local bounds for the current draw pass.
Sourcepub fn fill_path(&mut self, path: &Path<Pixels>, fill: impl Into<Background>)
pub fn fill_path(&mut self, path: &Path<Pixels>, fill: impl Into<Background>)
Fill an existing path with the given background.
Sourcepub fn stroke_path(&mut self, path: &Path<Pixels>, stroke: Stroke)
pub fn stroke_path(&mut self, path: &Path<Pixels>, stroke: Stroke)
Stroke a path using the retained source outline stored on the path.
Sourcepub fn stroke_line(
&mut self,
from: Point<Pixels>,
to: Point<Pixels>,
stroke: Stroke,
)
pub fn stroke_line( &mut self, from: Point<Pixels>, to: Point<Pixels>, stroke: Stroke, )
Stroke a straight line segment between two points.
Sourcepub fn fill_rect(&mut self, bounds: Bounds<Pixels>, fill: impl Into<Background>)
pub fn fill_rect(&mut self, bounds: Bounds<Pixels>, fill: impl Into<Background>)
Fill an axis-aligned rectangle.
Sourcepub fn fill_rounded_rect(
&mut self,
bounds: Bounds<Pixels>,
radii: impl Into<Corners<Pixels>>,
fill: impl Into<Background>,
)
pub fn fill_rounded_rect( &mut self, bounds: Bounds<Pixels>, radii: impl Into<Corners<Pixels>>, fill: impl Into<Background>, )
Fill a rounded rectangle.
Sourcepub fn fill_circle(
&mut self,
center: Point<Pixels>,
radius: Pixels,
fill: impl Into<Background>,
)
pub fn fill_circle( &mut self, center: Point<Pixels>, radius: Pixels, fill: impl Into<Background>, )
Fill a circle.
Sourcepub fn stroke_circle(
&mut self,
center: Point<Pixels>,
radius: Pixels,
stroke: Stroke,
)
pub fn stroke_circle( &mut self, center: Point<Pixels>, radius: Pixels, stroke: Stroke, )
Stroke a circle.
Sourcepub fn with_transform<R>(
&mut self,
matrix: TransformationMatrix,
f: impl FnOnce(&mut Self) -> R,
) -> R
pub fn with_transform<R>( &mut self, matrix: TransformationMatrix, f: impl FnOnce(&mut Self) -> R, ) -> R
Apply an affine transform to commands issued within the callback.
Sourcepub fn with_opacity<R>(
&mut self,
opacity: f32,
f: impl FnOnce(&mut Self) -> R,
) -> R
pub fn with_opacity<R>( &mut self, opacity: f32, f: impl FnOnce(&mut Self) -> R, ) -> R
Multiply the current drawing opacity for commands issued within the callback.
Sourcepub fn with_clip<R>(
&mut self,
bounds: Bounds<Pixels>,
f: impl FnOnce(&mut Self) -> R,
) -> R
pub fn with_clip<R>( &mut self, bounds: Bounds<Pixels>, f: impl FnOnce(&mut Self) -> R, ) -> R
Restrict drawing to an additional clip rectangle.